Welcome to SU2xSU2’s documentation! — SU2xSU2 1.0 documentation

# Welcome to SU2xSU2’s documentation!

This python package offers efficient simulation and data analysis routines for the SU(2) x SU(2) Principal Chiral model. The key feature offered is the integration of Fourier Acceleration into the Hybrid Monte Carlo algorithm which leads to a significant reduction in the degree of critical slowing down.

Check out the Usage section for further information, including how to install the project and some examples.

Note

Currently the simulation is only supported for a two dimensional cubic lattice.

Contents:

- Usage
  - Installation
  - Examples
- SU2xSU2
  - SU2xSU2 package

# Indices and tables

- Index

- Module Index

- Search Page